@@ -1,8 +1,8 @@
 ####################################################################
 #' Get Tweets
-#' 
+#'
 #' This function downloads tweets with personal credentials
-#' 
+#'
 #' @family Credentials
 #' @family Twitter
 #' @param q Query. Check for ?rtweet::search_tweets()
@@ -11,7 +11,6 @@
 #' @return data.frame with API response results.
 #' @export
 get_tweets <- function(q, n = 10000, creds = NA) {
-
   try_require("rtweet")
   c <- get_credentials(from = "twitter", dir = creds)
 
@@ -20,10 +19,10 @@ get_tweets <- function(q, n = 10000, creds = NA) {
     consumer_key = c$consumer_key,
     consumer_secret = c$consumer_secret,
     access_token = c$access_token,
-    access_secret = c$access_secret)
+    access_secret = c$access_secret
+  )
 
   out <- search_tweets(q = as.character(q), n = n, retryonratelimit = T)
 
   return(out)
-
 }
